==> ejc-proequipmentp-impl-3.0.0-20220330.030122-15-sources.jar: com/ejianc/business/purchase/bean/ChangePurchaseContractClauseEntity.java <==
package com.ejianc.business.purchase.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 购置合同-变更表-合同条款表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_proequipment_purchase_contract_change_clause")
public class ChangePurchaseContractClauseEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="code")
    private String code; // 单据编号
    @TableField(value="name")
    private String name; // 合同条款名称
    @TableField(value="clause_id")
    private Long clauseId; // 合同条款id
    @TableField(value="bill_state")
    private Integer billState; // 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
    @TableField(value="clause_content")
    private String clauseContent; // 合同条款内容
    @TableField(value="contract_id")
    private Long contractId; // 合同id
    @TableField(value="change_id")
    private Long changeId; // 变更id
    @TableField(value="src_tbl_id")
    private Long srcTblId; // 来源子表主键
    
    
    

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public Long getClauseId() {
        return clauseId;
    }

    public void setClauseId(Long clauseId) {
        this.clauseId = clauseId;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getClauseContent() {
        return clauseContent;
    }

    public void setClauseContent(String clauseContent) {
        this.clauseContent = clauseContent;
    }
    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }
    public Long getSrcTblId() {
        return srcTblId;
    }

    public void setSrcTblId(Long srcTblId) {
        this.srcTblId = srcTblId;
    }
    
}

==> ejc-proequipmentp-impl-3.0.0-20220330.121137-20-sources.jar: com/ejianc/business/purchase/bean/ChangePurchaseContractClauseEntity.java <==
package com.ejianc.business.purchase.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 购置合同-变更表-合同条款表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_proequipment_purchase_contract_change_clause")
public class ChangePurchaseContractClauseEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="code")
    private String code; // 单据编号
    @TableField(value="name")
    private String name; // 合同条款名称
    @TableField(value="clause_id")
    private Long clauseId; // 合同条款id
    @TableField(value="bill_state")
    private Integer billState; // 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
    @TableField(value="clause_content")
    private String clauseContent; // 合同条款内容
    @TableField(value="contract_id")
    private Long contractId; // 合同id
    @TableField(value="change_id")
    private Long changeId; // 变更id
    @TableField(value="src_tbl_id")
    private Long srcTblId; // 来源子表主键
    @TableField("necessary_status")
    private Boolean necessaryStatus;
    @TableField("necessary_status_name")
    private String necessaryStatusName;

    
    

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public Long getClauseId() {
        return clauseId;
    }

    public void setClauseId(Long clauseId) {
        this.clauseId = clauseId;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getClauseContent() {
        return clauseContent;
    }

    public void setClauseContent(String clauseContent) {
        this.clauseContent = clauseContent;
    }
    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }
    public Long getSrcTblId() {
        return srcTblId;
    }

    public void setSrcTblId(Long srcTblId) {
        this.srcTblId = srcTblId;
    }

    public Boolean getNecessaryStatus() {
        return necessaryStatus;
    }

    public void setNecessaryStatus(Boolean necessaryStatus) {
        this.necessaryStatus = necessaryStatus;
    }

    public String getNecessaryStatusName() {
        return necessaryStatusName;
    }

    public void setNecessaryStatusName(String necessaryStatusName) {
        this.necessaryStatusName = necessaryStatusName;
    }
}
